
from twisted.internet import reactor
from quarry.net.server import ServerFactory, ServerProtocol
import logging
import sys
import json

logging.basicConfig(format="[{asctime}] {message}", style="{", level=logging.INFO)
logger = logging.getLogger(__name__)

conifg_path = sys.argv[1]

with open(conifg_path, 'r') as f:
    config = json.load(f)

class Protocol(ServerProtocol):
    def player_joined(self):
        ServerProtocol.player_joined(self)

        player_display_name = self.display_name
        player_uuid = self.uuid.hex
        ip_address = self.remote_addr.host

        logger.info(f"Player '{player_display_name}' with the UUID of {player_uuid} has connected from {ip_address}")

        if player_uuid not in config['player_whitelist']:
            self.close(config['messages']['kick_not_whitelisted'])
            return

        self.close(config['messages']['kick_success'])

    def player_left(self):
        player_uuid = self.uuid.hex

        if player_uuid in config["player_whitelist"]:
            reactor.stop()

    def packet_received(self, buff, name):
        ip_address = self.remote_addr.host
        
        if name == 'status_ping':
            logger.info(f"Status ping received from {ip_address}")

        return super().packet_received(buff, name)

class Factory(ServerFactory):
    protocol = Protocol
    
    motd = config['messages']['motd']
    max_players = 1
    online_mode = True

def main():
    factory = Factory()

    logger.info(f"Server listening on port {config['port']}")

    factory.listen(config['host'], config['port'])
    reactor.run()

if __name__ == '__main__':
    main()